require 'spec_helper'

describe AgileSolo::Consumer do
  before do
    AgileSolo::Config.chef_repo = File.expand_path('./spec/chef_repo')
    @payload = MultiJson.load(fixture('items.json'))['solo']
    @consumer = AgileSolo::Consumer.new(@payload)
  end

  describe "#initialize" do
    it 'returns the given chef repository' do
      expect(@consumer.chef_repo).to eql AgileSolo::Config.chef_repo
    end

    it 'returns name attribute' do
      expect(@consumer.name).to eql @payload['name']
    end

    it 'returns run_list attribute' do
      expect(@consumer.run_list).to eql @payload['run_list']
    end

    it 'returns data attribute' do
      expect(@consumer.data).to eql MultiJson.dump(@payload['items'])
    end

    it 'returns the data_bag_path' do
      expect(Chef::Config[:data_bag_path]).to eql File.join(@consumer.chef_repo, 'data_bags')
    end

    it 'returns the config_file path' do
      expect(@consumer.chef_solo.config[:config_file]).to eql File.join(@consumer.chef_repo, 'solo.rb')
    end

    it 'returns the override_runlist path' do
      expect(@consumer.chef_solo.config[:override_runlist].include?(@consumer.run_list)).to be_true
    end
  end

  describe '#chef_solo' do
    it 'returns a solo object' do 
      expect(@consumer.chef_solo).to be_instance_of AgileSolo::Application::Solo
    end
  end

  describe '#execute' do
    it 'calls the overrided run_application method' do
      expect(@consumer.chef_solo).to receive(:run_application)
      @consumer.execute
    end
  end
end
